@@ -19,6 +19,8 @@ class ProperlyEvents(str, Enum):
     PPR_FEEDBACK = 'pprFeedback'
     FAVOURITE_ADDED = 'favouriteAdded'
     FAVOURITE_REMOVED = 'favouriteRemoved'
+    USER_DEAL_STAGES_CHANGED = 'userDealStagesChanged'
+    BEHAVIOUR_TRACK_EVENT = 'behaviourTrackEvent_gcL38BxP60q07RV4B2C3Cg'
 
 
 class EventBusBase:
