@@ -9,6 +9,7 @@ from properly_util_python.dynamo_data_utils import DynamoData
 from properly_util_python.schemas import UserSchema
 from properly_util_python.dynamo_helper import DynamoHelperBase
 
+from properly_util_python.data_utils import GuidUrlSafe
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -233,7 +234,21 @@ class UserAuthHelper:
 
         return "INVALID_ID_NOT_IMPLEMENTED"
 
+    def get_user_from_properly_user_id(self, properly_user_id: str):
+
+        response = self.user_table.get_item(Key={'id': properly_user_id})
+        item = response.get('Item')
+        return item
+
     def create_or_update_if_unverified(self, properly_user_id, auth_id: str, auth_email: str):
+        # if we have a new cognito user but are holding on to an old properly_user_id from a previous
+        # login with a different account, re-generate the requested properly_user_id so that account
+        # creation in dynamo can succeed
+        existing_user = self.get_user_from_properly_user_id(properly_user_id)
+        if existing_user != None and existing_user.get('authIdCognito') != auth_id and existing_user.get('unverifiedEmail') != auth_email:
+            logger.info(("Attempted to create account with existing properly user id {} ".format(properly_user_id)))
+            properly_user_id = GuidUrlSafe.generate()
+            logger.info("Generated new ID for creation: {} ".format(properly_user_id))
 
         seconds_epoch_now = int(time.time())
 
